@@ -5,11 +5,10 @@ from contextlib import contextmanager
 
 from pip._internal.utils.hashes import FAVORITE_HASH
 
-from .._compat import PIP_VERSION
-from .base import BaseRepository
-
 from piptools.utils import as_tuple, key_from_ireq, make_install_requirement
 
+from .base import BaseRepository
+
 
 def ireq_satisfied_by_existing_pin(ireq, existing_pin):
     """
@@ -33,7 +32,8 @@ class LocalRequirementsRepository(BaseRepository):
     PyPI.  This keeps updates to the requirements.txt down to a minimum.
     """
 
-    def __init__(self, existing_pins, proxied_repository):
+    def __init__(self, existing_pins, proxied_repository, reuse_hashes=True):
+        self._reuse_hashes = reuse_hashes
         self.repository = proxied_repository
         self.existing_pins = existing_pins
 
@@ -74,13 +74,11 @@ class LocalRequirementsRepository(BaseRepository):
         return self.repository.get_dependencies(ireq)
 
     def get_hashes(self, ireq):
-        key = key_from_ireq(ireq)
-        existing_pin = self.existing_pins.get(key)
+        existing_pin = self._reuse_hashes and self.existing_pins.get(
+            key_from_ireq(ireq)
+        )
         if existing_pin and ireq_satisfied_by_existing_pin(ireq, existing_pin):
-            if PIP_VERSION[:2] <= (20, 0):
-                hashes = existing_pin.options.get("hashes", {})
-            else:
-                hashes = existing_pin.hash_options
+            hashes = existing_pin.hash_options
             hexdigests = hashes.get(FAVORITE_HASH)
             if hexdigests:
                 return {
@@ -92,3 +90,6 @@ class LocalRequirementsRepository(BaseRepository):
     def allow_all_wheels(self):
         with self.repository.allow_all_wheels():
             yield
+
+    def copy_ireq_dependencies(self, source, dest):
+        self.repository.copy_ireq_dependencies(source, dest)
